#LiteGUIbatch V3
import tkinter as tk
from tkinter import filedialog, ttk, messagebox
import os
import subprocess
import threading

def run_ultra_singer():
    def process_files():
        input_files = input_file_text.get("1.0", tk.END).splitlines()
        output_folder = output_folder_entry.get()

        # Configure the determinate progress bar
        progress_bar["value"] = 0
        progress_bar["maximum"] = len(input_files)

        # Configure the indeterminate progress bar
        indeterminate_progress_bar.start()

        for index, input_file in enumerate(input_files, start=1):
            command = [
                "python3",
                "src/UltraSinger.py",
                "-i",
                input_file,
                "-o",
                output_folder
            ]

            process = subprocess.Popen(command, shell=False)
            process.wait()

            # Remove the processed file from the text box
            input_file_text.delete("1.0", "2.0")

            # Update the determinate progress bar
            progress_bar.step(1)

            # Update the percentage label
            percentage_text.set(f"{(index / len(input_files)) * 100:.2f}%")

        # All files processed, stop both progress bars
        indeterminate_progress_bar.stop()
        progress_bar.stop()

        # Reset the percentage label
        percentage_text.set("")

        # Show notification
        show_notification("Processing Complete", "All files have been processed.")

    # Create a separate thread for file processing
    processing_thread = threading.Thread(target=process_files)
    processing_thread.start()

def show_notification(title, message):
    messagebox.showinfo(title, message)

def browse_input_file():
    file_paths = filedialog.askopenfilenames(
        initialdir=os.getcwd(),
        title="Select Input Files",
        filetypes=(("Audio Files", ".mp3 .wav .ogg"),)
    )
    
    for file_path in file_paths:
        input_file_text.insert(tk.END, file_path + "\n")

def browse_output_folder():
    folder_path = filedialog.askdirectory(
        initialdir=os.getcwd(),
        title="Select Output Folder"
    )
    output_folder_entry.delete(0, tk.END)
    output_folder_entry.insert(0, folder_path)

root = tk.Tk()
root.title("UltraSinger GUI Lite Batch")

# Set the window size with a 16:10 aspect ratio
window_width = 800
window_height = int(window_width * 10 / 16)
root.geometry(f"{window_width}x{window_height}")

# Determinate Progress Bar
progress_bar = ttk.Progressbar(root, mode="determinate", length=780)
progress_bar.grid(row=0, column=0, padx=10, pady=10, columnspan=3, sticky="w")  # Adjusted row

# Percentage Label
Percentageadd_label = tk.Label(root, 
	text="              Finnished", 
	font=("Helvetica", 16)
)
Percentageadd_label.grid(row=1, column=1, padx=0, pady=10, sticky="w")
percentage_text = tk.StringVar()
percentage_text.set("0.00%")
percentage_label = tk.Label(
    root,
    textvariable=percentage_text,
    font=("Helvetica", 16),  # Change the font size and family as needed
    width=5  # Adjust width to center the label
)
percentage_label.grid(row=1, column=1, padx=10, pady=10, sticky="w")  # Adjusted properties

# Input File
input_file_label = tk.Label(root, text="Input Files/URLs:")
input_file_label.grid(row=2, column=0, padx=10, pady=5, sticky="nw")
input_file_text = tk.Text(root, wrap="none", height=20, width=59)
input_file_text.grid(row=2, column=1, padx=0, pady=0, sticky="w")
browse_input_button = tk.Button(root, text="Browse", command=browse_input_file, width=15, height=4)
browse_input_button.grid(row=2, column=2, padx=30, pady=0, sticky="w")

# Output Folder
output_folder_label = tk.Label(root, text="Output Folder:")
output_folder_label.grid(row=3, column=0, padx=10, pady=5, sticky="w")
output_folder_entry = tk.Entry(root, width=45)
output_folder_entry.grid(row=3, column=1, padx=0, pady=0, sticky="w")
browse_output_button = tk.Button(root, text="Browse", command=browse_output_folder, width=15, height=4)
browse_output_button.grid(row=3, column=2, padx=30, pady=20, sticky="w")

# Indeterminate Progress Bar
indeterminate_progress_bar = ttk.Progressbar(root, mode="indeterminate", length=500)
indeterminate_progress_bar.grid(row=4, column=0, padx=0, pady=0, columnspan=2, sticky="ns")  # Adjusted row

# Run Button
run_button = tk.Button(root, text="Run UltraSinger", command=run_ultra_singer, width=20, height=2)
run_button.grid(row=4, column=2, padx=30, pady=0, columnspan=2, sticky="e")  # Adjusted row

# Start the Tkinter main loop
root.mainloop()
