#Cap V2
import tkinter as tk
from tkinter import filedialog, messagebox
from pathlib import Path

def calculate_time_variable(line):
    _, time_info = line.split(" ", 1)
    time_parts = time_info.split()
    if len(time_parts) >= 2:
        start_time, duration = map(int, time_parts[:2])
        return start_time + duration
    return 0  # Return 0 if there are not enough values

def process_file(file_path, delete_lines_flag):
    with open(file_path, 'r') as file:
        lines = file.readlines()

    modified_lines = []
    check_next_line = False
    last_hyphen_index = -3  # Initialize to a value that won't interfere with the first check

    for i, line in enumerate(lines):
        if delete_lines_flag and line.startswith('-'):
            continue  # Skip lines starting with "-" if the checkbox is selected

        if check_next_line and '-' not in line and i - last_hyphen_index >= 3:
            if any(char.isupper() for char in line.strip()):
                modified_lines.append('- ' + str(calculate_time_variable(modified_lines[-1])) + "\n")
                last_hyphen_index = i

        modified_lines.append(line)
        check_next_line = False

        if line.startswith(':'):
            check_next_line = True

    output_path = Path(file_path).parent / ('Modified_' + Path(file_path).name)
    with open(output_path, 'w') as modified_file:
        modified_file.write(''.join(modified_lines))

    return output_path

def browse_files():
    file_paths = filedialog.askopenfilenames(filetypes=[("Text files", "*.txt")])
    for file_path in file_paths:
        files_listbox.insert(tk.END, file_path)

def show_notification(output_path):
    messagebox.showinfo("Processing Completed", f"Processing completed. Output file: {output_path}")

def process_files():
    selected_files = files_listbox.get(0, tk.END)
    delete_lines_flag = delete_lines_var.get()  # Get the state of the checkbox

    for file_path in selected_files:
        output_path = process_file(file_path, delete_lines_flag)
        show_notification(output_path)

# GUI setup
root = tk.Tk()
root.title("Karaoke Song Processor")

# Listbox to display selected files
files_listbox = tk.Listbox(root, selectmode=tk.MULTIPLE, width=50)
files_listbox.pack(pady=10)

# Checkbox to enable or disable deletion of lines starting with "-"
delete_lines_var = tk.BooleanVar()
delete_lines_checkbox = tk.Checkbutton(root, text="Delete lines starting with '-'", variable=delete_lines_var)
delete_lines_checkbox.pack()

# Browse button to select files
browse_button = tk.Button(root, text="Browse Files", command=browse_files)
browse_button.pack()

# Process button to modify files
process_button = tk.Button(root, text="Process Files", command=process_files)
process_button.pack(pady=10)

# Start the Tkinter event loop
root.mainloop()
